Examples
========

Below you can find examples.


.. toctree::
    :maxdepth: 4
    :hidden:
    :glob:

    bruggeman_21_11
    bruggeman_123_05
    bruggeman_126_33
    bruggeman_128_0x
    bruggeman_133_16
    edelman
    bruggeman_355_19
    check_ierfc


Flow1D
------

`21.11 Confined phreatic aquifer with precipitation`_

`123.05 Constant pumping in a confined aquifer`_

`126.33 Step head change in a semi-confined aquifer - steady state`_

`128.0x Tidal fluctuation of open water`_

`133.1x Confined flow with precipitation`_

`Edelman sudden change in water level in a confined aquifer`_

.. _21.11 Confined phreatic aquifer with precipitation: bruggeman_21_11.html
.. _123.05 Constant pumping in a confined aquifer: bruggeman_123_05.html
.. _126.33 Step head change in a semi-confined aquifer - steady state: bruggeman_126_33.html
.. _128.0x Tidal fluctuation of open water: bruggeman_128_0x.html
.. _133.1x Confined flow with precipitation: bruggeman_133_1x.html
.. _Edelman sudden change in water level in a confined aquifer: edelman.html

Flow2D
------

`355.19 Drainage canal on top of confined aquifer`_

.. _355.19 Drainage canal on top of confined aquifer: bruggeman_355_19.html

Other
-----

`Iterated integral complementary error function`_

.. _Iterated integral complementary error function: check_ierfc.html
